"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class DashboardTokenResponseTypedDict(TypedDict):
    r"""Basic information about a dashboard."""

    embedded_id: str
    r"""Superset embedded ID of the dashboard"""
    guest_token: str
    r"""Superset guest token of the dashboard"""
    name: str
    r"""Name of the dashboard"""
    display_name: str
    r"""Display name of the dashboard"""
    superset_url: str
    r"""Superset URL of the dashboard"""
    rank: int
    r"""Dashboard importance, 0 is the highest"""
    label: str
    r"""Dashboard label.  Typically report or dashboard"""


class DashboardTokenResponse(BaseModel):
    r"""Basic information about a dashboard."""

    embedded_id: str
    r"""Superset embedded ID of the dashboard"""

    guest_token: str
    r"""Superset guest token of the dashboard"""

    name: str
    r"""Name of the dashboard"""

    display_name: str
    r"""Display name of the dashboard"""

    superset_url: str
    r"""Superset URL of the dashboard"""

    rank: int
    r"""Dashboard importance, 0 is the highest"""

    label: str
    r"""Dashboard label.  Typically report or dashboard"""
