"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class DialogToolCallToolArgumentsTypedDict(TypedDict):
    pass


class DialogToolCallToolArguments(BaseModel):
    pass


class DialogToolCallTypedDict(TypedDict):
    tool_call_id: str
    tool_name: str
    tool_arguments: DialogToolCallToolArgumentsTypedDict
    timestamp: datetime


class DialogToolCall(BaseModel):
    tool_call_id: str

    tool_name: str

    tool_arguments: DialogToolCallToolArguments

    timestamp: datetime
