"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sessionmessage import SessionMessage, SessionMessageTypedDict
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SessionDataTypedDict(TypedDict):
    session_id: int
    source: str
    target: str
    is_test: bool
    messages: List[SessionMessageTypedDict]


class SessionData(BaseModel):
    session_id: int

    source: str

    target: str

    is_test: bool

    messages: List[SessionMessage]
