"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class ToolResultTypedDict(TypedDict):
    pass


class ToolResult(BaseModel):
    pass


class ToolResultDataTypedDict(TypedDict):
    tool_name: str
    tool_result: ToolResultTypedDict


class ToolResultData(BaseModel):
    tool_name: str

    tool_result: ToolResult
