"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class InsightWorkflowInputConditionsTypedDict(TypedDict):
    r"""Conditions for Insight Workflow"""


class InsightWorkflowInputConditions(BaseModel):
    r"""Conditions for Insight Workflow"""


class InsightWorkflowInputTypedDict(TypedDict):
    name: str
    r"""Human readable name of Insight Workflow"""
    description: str
    r"""Text description of Insight Workflow"""
    insight_tool_ids: List[int]
    r"""List of Insight Tool IDs"""
    conditions: InsightWorkflowInputConditionsTypedDict
    r"""Conditions for Insight Workflow"""
    status: str
    r"""Status of the Insight Workflow"""


class InsightWorkflowInput(BaseModel):
    name: str
    r"""Human readable name of Insight Workflow"""

    description: str
    r"""Text description of Insight Workflow"""

    insight_tool_ids: List[int]
    r"""List of Insight Tool IDs"""

    conditions: InsightWorkflowInputConditions
    r"""Conditions for Insight Workflow"""

    status: str
    r"""Status of the Insight Workflow"""
